@@ -52,6 +52,10 @@ class IdentityTransformation(AbstractTransformation):
     def inverse(self):
         return self
 
+    @property
+    def is_one_to_many(self):
+        return False
+
     @property
     def to_dict(self):
         output = {'name' : self.__class__.__name__, 'init_args': {}, 'version': __version__ }
@@ -90,6 +94,10 @@ class RotationTransformation(AbstractTransformation):
     def inverse(self):
         return RotationTransformation(self._axis, -self._angle, self._angle_in_radians)
 
+    @property
+    def is_one_to_many(self):
+        return False
+
     @property
     def to_dict(self):
         output = {'name' : self.__class__.__name__, 'version': __version__}
@@ -118,6 +126,10 @@ class OxidationStateDecorationTransformation(AbstractTransformation):
     def inverse(self):
         return None
 
+    @property
+    def is_one_to_many(self):
+        return False
+
     @property
     def to_dict(self):
         output = {'name' : self.__class__.__name__, 'version': __version__}
@@ -173,6 +185,10 @@ class SupercellTransformation(AbstractTransformation):
     def inverse(self):
         raise NotImplementedError()
 
+    @property
+    def is_one_to_many(self):
+        return False
+
     @property
     def to_dict(self):
         output = {'name' : self.__class__.__name__, 'version': __version__}
@@ -218,6 +234,10 @@ class SubstitutionTransformation(AbstractTransformation):
     def inverse(self):
         return SubstitutionTransformation({v:k for k, v in self._species_map.items()})
 
+    @property
+    def is_one_to_many(self):
+        return False
+
     @property
     def to_dict(self):
         output = {'name' : self.__class__.__name__, 'version': __version__}
@@ -252,6 +272,10 @@ class RemoveSpeciesTransformation(AbstractTransformation):
     def inverse(self):
         return None
 
+    @property
+    def is_one_to_many(self):
+        return False
+
     @property
     def to_dict(self):
         output = {'name' : self.__class__.__name__, 'version': __version__}
@@ -318,6 +342,10 @@ class PartialRemoveSpecieTransformation(AbstractTransformation):
         trans = PartialRemoveSitesTransformation([specie_indices], [self._frac], self._algo)
         return trans.apply_transformation(structure, return_ranked_list)
 
+    @property
+    def is_one_to_many(self):
+        return True
+
     def __str__(self):
         return "PartialRemoveSpecieTransformation : Species to remove = {}, Fraction to remove = {}, ALGO = {}".format(self._specie, self._frac, self._algo)
 
@@ -488,16 +516,16 @@ class OrderDisorderedStructureTransformation(AbstractTransformation):
     def inverse(self):
         return None
 
+    @property
+    def is_one_to_many(self):
+        return True
+
     @property
     def to_dict(self):
         output = {'name' : self.__class__.__name__, 'version': __version__}
         output['init_args'] = {'num_structures' : self._num_structures, 'energy_cutoff' : self._energy_cutoff}
         return output
 
-    @property
-    def all_structures(self):
-        return self._all_structures
-
     @property
     def lowest_energy_structure(self):
         return self._all_structures[0]['structure']
@@ -613,7 +641,6 @@ class PrimitiveCellTransformation(AbstractTransformation):
             structure2 = self._get_more_primitive_structure(structure, self._tolerance)
         return structure2
 
-
     def __str__(self):
         return "Primitive cell transformation"
 
@@ -624,6 +651,10 @@ class PrimitiveCellTransformation(AbstractTransformation):
     def inverse(self):
         return None
 
+    @property
+    def is_one_to_many(self):
+        return False
+
     @property
     def to_dict(self):
         output = {'name' : self.__class__.__name__, 'version': __version__}
@@ -663,7 +694,11 @@ class ChargeBalanceTransformation(AbstractTransformation):
 
     @property
     def inverse(self):
-        return self
+        return None
+
+    @property
+    def is_one_to_many(self):
+        return False
 
     @property
     def to_dict(self):
